from setuptools import setup

setup(
    name='popupsort',
    version='1.0',
    description='A program for visualizing sorting algorithms',
    author='Zouheir Nakouzi',
    author_email='zouheir2002@gmail.com',
    url='https://github.com/ZouheirN/PopUpSort',
    packages=['popupsort'],
    zip_safe=False)
